@@ -181,27 +181,29 @@ class Bootstrap:
 
             gevent.spawn(update_status)
 
-            console.print(f"Spawning virtual machine at {host.__class__.__name__}")
-            machine = web.host.spawn_machine(self.website, host)
-            console.print("Updating system")
-            machine._apt("update")
-            console.print("Installing firewall")
-            machine._apt("install -yq ufw")
-            machine.open_ports(22)
-            console.print("Setting up system")
-            machine.setup_machine()
-            console.print("Installing python")
-            machine.setup_python()
-            console.print("Installing tor")
-            machine.setup_tor()
-            # XXX machine = web.host.Machine("143.110.230.47", "root", "gaea_key")
-            # XXX machine.onion = (
-            # XXX   "izxwrqchdaqpj2iphrqoh6govp4dqolem4epoxv2nijqvlo5q3kbd5qd.onion"
-            # XXX )
+            # console.print(f"Spawning virtual machine at {host.__class__.__name__}")
+            # machine = web.host.spawn_machine(self.website, host)
+            # console.print("Updating system")
+            # machine._apt("update")
+            # console.print("Installing firewall")
+            # machine._apt("install -yq ufw")
+            # machine.open_ports(22)
+            # console.print("Setting up system")
+            # machine.setup_machine()
+            # console.print("Installing python")
+            # machine.setup_python()
+            # console.print("Installing tor")
+            # machine.setup_tor()
+
+            machine = web.host.Machine("128.199.1.111", "root", "gaea_key")
+            machine.onion = (
+                "hxpcvad6txrivhondry6htgmlc2idrxz37ofyobe7ynxpdxd7xdn5sid.onion"
+            )
+
             console.print("Installing nginx")
             machine.setup_nginx()
-            console.print(f"Installing application: {self.app} of {self.package}")
-            machine.setup_app(self.package, self.app)
+            # console.print(f"Installing application: {self.app} of {self.package}")
+            # machine.setup_app(self.package, self.app, config["host_token"])
             time.sleep(2)
         console.rule(
             f"[green]Bootstrapped {self.package} ({self.app}) at {machine.address}"
